import 'package:flutter/material.dart';
import 'package:plugin_codelab_new/pages/comments/providers/messages_provider.dart';
import 'package:plugin_codelab_new/pages/home_page.dart';
import 'package:plugin_codelab_new/repo/feed_repository.dart';
import 'package:plugin_codelab_new/service/http_service.dart';

import 'bloc/feed_cubit.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:provider/provider.dart';

class FeedPlugin extends StatelessWidget {
  const FeedPlugin({
    Key key,
    @required this.token,
    @required this.firstName,
    @required this.lastName,
    @required this.about,
    @required this.profileImg,
  }) : super(key: key);

  final String token;
  final String firstName;
  final String lastName;
  final String about;
  final String profileImg;

  @override
  Widget build(BuildContext context) {
    return init();
  }

  Widget init() {
    final httpService = HttpService("gogog");
    final feedRepository = FeedRepository(httpService);
    final feedCubit = FeedCubit(feedRepository: feedRepository);
    runApp(
      MultiRepositoryProvider(
        providers: [
          RepositoryProvider<FeedRepository>(
            create: (context) => FeedRepository(httpService),
          )
        ],
        child: MultiBlocProvider(providers: [
          BlocProvider<FeedCubit>(
            create: (context) {
              return feedCubit;
            },
          ),
        ], child: app()),
      ),
    );
    return app();
  }

  Widget app() {
    return ChangeNotifierProvider.value(
      value: MessagesProvider(),
      child: MaterialApp(
        title: 'Flutter Socket IO Chat',
        debugShowCheckedModeBanner: false,
        theme: ThemeData(
          primarySwatch: Colors.teal,
          accentColor: Colors.pink.withOpacity(.8),
          textTheme: TextTheme(
            title: TextStyle(color: Colors.white),
          ),
        ),
        home: HomePage(
          token: this.token,
          firstName: this.firstName,
          lastName: this.lastName,
          about: this.about,
          profileImg: this.profileImg,
        ),
        routes: <String, WidgetBuilder>{
          '/homePage': (BuildContext context) => new HomePage(
                token: this.token,
                firstName: this.firstName,
                lastName: this.lastName,
                about: this.about,
                profileImg: this.profileImg,
              ),
        },
      ),
    );
  }
}
