import 'package:bubble/bubble.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:timeago/timeago.dart' as timeago;

import '../../models/message.dart';

class MessagesItem extends StatelessWidget {
  final Message _message;

  final bool isUserMassage;

  const MessagesItem(this._message, this.isUserMassage);

  @override
  Widget build(BuildContext context) {
    final date2 = DateTime.now();
    final difference = date2.difference(_message.date).inMinutes;
    final fifteenAgo =
        new DateTime.now().subtract(new Duration(minutes: difference));
    BubbleStyle styleSomebody = BubbleStyle(
      nip: BubbleNip.leftTop,
      elevation: 1,
      margin: BubbleEdges.only(
        top: ScreenUtil().setWidth(8),
        right: ScreenUtil().setWidth(10),
        left: ScreenUtil().setWidth(50),
      ),
      alignment: Alignment.topLeft,
    );
    BubbleStyle styleImageSomebody = BubbleStyle(
      color: Colors.white.withOpacity(0),
      elevation: 0,
      margin: BubbleEdges.only(
        top: ScreenUtil().setWidth(8),
      ),
      alignment: Alignment.topLeft,
    );

    return Column(
      children: [
        Stack(
          children: [
            Bubble(
              style: styleImageSomebody,
              child: ClipOval(
                child: Image.network(
                  _message.senderImage,
                  width: ScreenUtil().setWidth(36),
                  height: ScreenUtil().setHeight(26),
                  fit: BoxFit.cover,
                ),
              ),
            ),
            Bubble(
              style: styleSomebody,
              color: isUserMassage ? Color(0xffE8ECEF) : Color(0xffE8ECEF),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(children: [
                    Text(_message.senderName),
                    Text(
                      " -" + timeago.format(fifteenAgo, locale: 'en_short'),
                      style: TextStyle(color: Color(0xff98A9BC)),
                    )
                  ]),
                  Text(_message.about,
                      style: TextStyle(color: Color(0xff98A9BC))),
                  Text(""),
                  Text(
                    _message.content,
                    style: TextStyle(fontSize: ScreenUtil().setSp(16)),
                  ),
                ],
              ),
            ),
          ],
        ),
      ],
    );
  }
}
